/*
** Module   : ControlTextWidget.java
** Abstract : server side text widget implementation
**
** Copyright (c) 2005-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 NVS 20051026   @23488 Created initial version.
** 002 SIY 20060202   @24234 Added support for NO-LABELS widget flag.
** 003 GES 20060208   @24381 Removed setFormat() since this was hiding
**                           the version implemented in ComponentConfig
**                           and it was also redundant.
** 004 SIY 20060209   @24431 Moved methods to base class.
** 005 SIY 20060316   @25128 Added support for header flag.
** 006 SIY 20060426   @25912 Changed signatures of getNextTabItem.
** 007 GES 20060627   @27649 Removed setPfColor/getPfColor methods which
**                           were only placed here to block usage by
**                           throwing an exception in our implementation.
**                           This attribute is valid and must not be
**                           blocked (they are implemented in one of the
**                           parent classes in our inheritance hierarchy). 
** 008 SIY 20060710   @27983 Added static widget content flag.
** 009 SIY 20060717   @28082 Added @ widget flag.
** 010 GES 20060803   @28372 Cleanup and refactoring.
** 011 NVS 20070418   @33104 Removed getNextTabItem() method which was
**                           only placed here to block usage by
**                           throwing an exception in our implementation.
**                           This attribute is valid and must not be
**                           blocked (they are implemented in one of the
**                           parent classes in our inheritance hierarchy).
** 012 GES 20080320   @37584 Added TYPE attribute.
** 013 SIY 20111101          Updated imports.
** 014 CA  20130221          Refactored usage of TYPE attribute.
*/ 

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Represents common function for text oriented widgets.
 */
public class ControlTextWidget
extends ControlEntity
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private ControlTextConfig ctc = null;
   
   /**
    * Default constructor.
    */
   public ControlTextWidget()
   {
      super(new ControlTextConfig(ComponentConfig.TEXT, null));
      ctc = (ControlTextConfig) config;
      
      setResourceType(ctc.isStatic() ? "LITERAL" : "TEXT");
   }
   
   /**
    * Constructor for use by sub-classes.
    *
    * @param   ctc
    *          Configuration container.
    */
   public ControlTextWidget(ControlTextConfig ctc)
   {
      super(ctc);
      this.ctc = ctc;

      setResourceType(ctc.isStatic() ? "LITERAL" : "TEXT");
   }
   
   /**
    * Set header flag which marks widget used as frame header.
    * 
    * @param   b
    *          New state of the flag.
    */
   public void setHeader(boolean b)
   {
      ctc.setHeader(b);
      frame.pushScreenDefinition();
   }

   /**
    * Set static widget content flag.
    * <p>
    * When this widget was created by the use of static data (a constant
    * or literal in the source code) and was created in a FORM or DEFINE
    * FRAME statement, then this flag should be set.
    * 
    * @param   flagStatic
    *          New value for the flag.
    */
   public void setStatic(boolean flagStatic)
   {
      ctc.setStatic(flagStatic);
   }

   /**
    * Set @ widget flag.
    * 
    * @param   flag
    *          New value for the flag.
    */
   public void setAt(boolean flag)
   {
      ctc.setAtField(flag);
   }
}
