/*
** Module   : SOAPHeader.java
** Abstract : Interface defining attributes/methods for SOAP-HEADER resource.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --------------------------------Description-----------------------------------
** 001 CA  20130216 Created initial version.
** 002 CA  20130221 Added ADM-DATA and UNIQUE-ID.
*/

package com.goldencode.p2j.util;

/**
 * Interface describing the features for SOAP-HEADER resource:
 * <ul>
 *    <li>{@link #getNumHeaderEntries NUM-HEADER-ENTRIES attribute}</li>
 *    <li>{@link #addHeaderEntry ADD-HEADER-ENTRY method}</li>
 *    <li>{@link #getHeaderEntry GET-HEADER-ENTRY method}</li>
 * </ul>
 */
public interface SOAPHeader
extends ADMData,
        UniqueID
{
   /**
    * Returns the number of SOAP-HEADER-ENTRYREF object entries attached to the SOAP-HEADER 
    * object.
    * 
    * @return   See above.
    */
   public integer getNumHeaderEntries();

   /**
    * Creates a new entry in a SOAP-header object’s list of entries and associates the new entry 
    * with the given SOAP-HEADER-ENTRY-REF object.
    * 
    * @param    entryRef
    *           The handle where the resource will be set.

    * @return   <code>true</code> if the operation was possible.
    */
   public logical addHeaderEntry(handle entryRef);

   /**
    * Get the header entry at the given index and assign it to the given handle.
    * <p>
    * This method returns a logical even though the Progress 4GL documentation explicitly states 
    * otherwise. Actual working code has proven that the original documentation is incorrect. 
    * This implementation matches the actual runtime behavior of the 4GL.
    * 
    * @param    target
    *           The handle where the SOAP-HEADER-ENTRY instance will be saved.
    * @param    idx
    *           The index of the SOAP-HEADER-ENTRY instance to retrieve. 4GL allows only integer
    *           and int64 values to be passed to this parameter.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical getHeaderEntry(handle target, long idx);

   /**
    * Get the header entry at the given index and assign it to the given handle.
    * <p>
    * This method returns a logical even though the Progress 4GL documentation explicitly states 
    * otherwise. Actual working code has proven that the original documentation is incorrect. 
    * This implementation matches the actual runtime behavior of the 4GL.
    * 
    * @param    target
    *           The handle where the SOAP-HEADER-ENTRY instance will be saved.
    * @param    idx
    *           The index of the SOAP-HEADER-ENTRY instance to retrieve. 4GL allows only integer
    *           and int64 values to be passed to this parameter.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical getHeaderEntry(handle target, integer idx);

   /**
    * Get the header entry at the given index and assign it to the given handle.
    * <p>
    * This method returns a logical even though the Progress 4GL documentation explicitly states 
    * otherwise. Actual working code has proven that the original documentation is incorrect. 
    * This implementation matches the actual runtime behavior of the 4GL.
    * 
    * @param    target
    *           The handle where the SOAP-HEADER-ENTRY instance will be saved.
    * @param    idx
    *           The index of the SOAP-HEADER-ENTRY instance to retrieve. 4GL allows only integer
    *           and int64 values to be passed to this parameter.
    * 
    * @return   <code>true</code> if the operation was possible.
    */
   public logical getHeaderEntry(handle target, int64 idx);
}
