/*
** Module   : Sizeable.java
** Abstract : Defines getters for width/height of the widget or the display
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 VMN 20130217 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Defines setters and getters for the WIDTH-CHARS, WIDTH-PIXELS and HEIGHT-CHARS, HEIGHT-PIXES
 * attributes.
 */
public interface Sizeable
{
   /**
    * Queries the WIDTH-PIXELS attribute of this widget.
    *
    * @return   The width of the widget in pixels.
    */
   public integer getWidthPixels();

   /**
    * Sets new value of WIDTH-PIXELS attribute.
    *
    * @param    widthPixels
    *           new value of WIDTH-PIXELS attribute
    */
   public void setWidthPixels(NumberType widthPixels);

   /**
    * Sets new value of WIDTH-PIXELS attribute.
    *
    * @param    widthPixels
    *           new value of WIDTH-PIXELS attribute
    */
   public void setWidthPixels(double widthPixels);

   /**
    * Queries the HEIGHT-PIXELS attribute of this widget.
    *
    * @return   The height of the widget in pixels.
    */
   public integer getHeightPixels();

   /**
    * Sets new value of HEIGHT-PIXELS attribute.
    *
    * @param    widthPixels
    *           new value of HEIGHT-PIXELS attribute
    */
   public void setHeightPixels(NumberType widthPixels);

   /**
    * Sets new value of HEIGHT-PIXELS attribute.
    *
    * @param    widthPixels
    *           new value of HEIGHT-PIXELS attribute
    */
   public void setHeightPixels(double widthPixels);

   /**
    * Get the WIDTH-CHARS Progress attribute. The value is equal to the current component char
    * width.
    *
    * @return    The integer value of the WIDTH-CHARS attribute.
    */
   public decimal getWidthChars();

   /**
    * Set the WIDTH-CHARS Progress attribute.
    *
    * @param    widthChars
    *           The integer value for the new WIDTH-CHARS value.
    */
   public void setWidthChars(double widthChars);

   /**
    * Set the WIDTH-CHARS Progress attribute.
    *
    * @param    widthChars
    *           The integer value for the new WIDTH-CHARS value.
    */
   public void setWidthChars(NumberType widthChars);

   /**
    * Get HEIGHT-CHARS attribute value.
    *
    * @return   Current value of the attribute.
    */
   public decimal getHeightChars();

   /**
    * Setting the HEIGHT-CHARS Progress attribute.
    *
    * @param    heightChars
    *           The integer value for the new HEIGHT-CHARS value.
    */
   public void setHeightChars(double heightChars);

   /**
    * Setting the HEIGHT-CHARS Progress attribute.
    *
    * @param    heightChars
    *           The integer value for the new HEIGHT-CHARS value.
    */
   public void setHeightChars(NumberType heightChars);
}
